@@ -58,11 +58,11 @@
 
 // Libmuon includes
 #include <resources/AbstractResource.h>
-#include <resources/AbstractResourcesBackend.h>
 #include <MuonStrings.h>
 #include <ReviewsBackend/Rating.h>
 #include <ReviewsBackend/Review.h>
 #include <ReviewsBackend/AbstractReviewsBackend.h>
+#include <Transaction/TransactionListener.h>
 #include <resources/AbstractResource.h>
 
 // std includes
@@ -291,12 +291,13 @@ ResourceDetailsWidget::ResourceDetailsWidget(QWidget *parent)
     layout->addWidget(detailsWidget);
     layout->addWidget(m_reviewsWidget);
     layout->addWidget(verticalSpacer);
+    
+    m_listener = new TransactionListener(this);
 
-    // FIXME
-//    connect(m_listener, SIGNAL(progressChanged()), SLOT(progressChanged()));
-//    connect(m_listener, SIGNAL(commentChanged()), SLOT(progressCommentChanged()));
-//    connect(m_listener, SIGNAL(running(bool)), SLOT(applicationRunningChanged(bool)));
-//    connect(m_listener, SIGNAL(downloading(bool)), SLOT(applicationDownloadingChanged(bool)));
+    connect(m_listener, SIGNAL(progressChanged()), SLOT(progressChanged()));
+    connect(m_listener, SIGNAL(commentChanged()), SLOT(progressCommentChanged()));
+    connect(m_listener, SIGNAL(running(bool)), SLOT(applicationRunningChanged(bool)));
+    connect(m_listener, SIGNAL(downloading(bool)), SLOT(applicationDownloadingChanged(bool)));
 
     setWidget(widget);
 }
@@ -309,7 +310,8 @@ ResourceDetailsWidget::~ResourceDetailsWidget()
 void ResourceDetailsWidget::setResource(AbstractResource *resource)
 {
     m_resource = resource;
-//    m_listener->setResource(m_resource);
+    m_listener->setResource(m_resource);
+    m_listener->setBackend(m_resource->backend());
 
     AbstractResource *app = qobject_cast<AbstractResource*>(resource);
 
@@ -521,14 +523,12 @@ void ResourceDetailsWidget::applicationDownloadingChanged(bool downloading)
 
 void ResourceDetailsWidget::progressChanged()
 {
-    // FIXME
-    //m_progressBar->setValue(m_listener->progress());
+    m_progressBar->setValue(m_listener->progress());
 }
 
 void ResourceDetailsWidget::progressCommentChanged()
 {
-    // FIMXE
-    //m_progressBar->setFormat(m_listener->comment());
+    m_progressBar->setFormat(m_listener->comment());
 }
 
 void ResourceDetailsWidget::updateActionButton()
