@@ -27,36 +27,32 @@
 #include <KDebug>
 #include <QFile>
 
-Category::Category(QObject* parent)
+Category::Category(const QDomNode& data, bool canHaveChildren, QObject* parent)
         : QObject(parent)
         , m_iconString("applications-other")
         , m_showTechnical(false)
-{}
+{
+    parseData(data, canHaveChildren);
+}
 
 Category::~Category()
 {}
 
-void Category::parseData(const QString& path, const QDomNode& data, bool canHaveChildren)
+void Category::parseData(const QDomNode& data, bool canHaveChildren)
 {
     if(!canHaveChildren) {
         m_name = i18nc("@label The label used for viewing all members of this category", "All");
     }
-
-    for(QDomNode node = data.firstChild(); !node.isNull(); node = node.nextSibling())
+    QDomNode node = data.firstChild();
+    while(!node.isNull())
     {
-        if(!node.isElement()) {
-            if(!node.isComment())
-                kWarning() << "unknown node found at " << QString("%1:%2").arg(path).arg(node.lineNumber());
-            continue;
-        }
         QDomElement tempElement = node.toElement();
 
         if (canHaveChildren) {
             if (tempElement.tagName() == QLatin1String("Name")) {
                 m_name = i18nc("Category", tempElement.text().toUtf8());
             } else if (tempElement.tagName() == QLatin1String("Menu")) {
-                m_subCategories << new Category(this);
-                m_subCategories.last()->parseData(path, node, true);
+                m_subCategories << new Category(node, true, this);
             }
         }
         
@@ -67,11 +63,12 @@ void Category::parseData(const QString& path, const QDomNode& data, bool canHave
         } else if (tempElement.tagName() == QLatin1String("Include")) {
             parseIncludes(tempElement);
         }
+
+        node = node.nextSibling();
     }
 
     if (!m_subCategories.isEmpty()) {
-        m_subCategories << new Category(this);
-        m_subCategories.last()->parseData(path, data, false);
+        m_subCategories << new Category(data, false, this);
     }
 }
 
@@ -184,8 +181,7 @@ QList< Category* > Category::loadCategoriesFile(const QString& path)
     QDomNode node = root.firstChild();
     while(!node.isNull())
     {
-        ret << new Category(nullptr);
-        ret.last()->parseData(path, node, true);
+        ret << new Category(node, true, nullptr);
 
         node = node.nextSibling();
     }
