@@ -33,18 +33,10 @@
 #include <KVBox>
 #include <Phonon/MediaObject>
 
-#ifdef QAPT_ENABLED
-#include <QAptActions.h>
-#endif
-
 MuonMainWindow::MuonMainWindow()
     : KXmlGuiWindow(0)
-    , m_canExit(false)
-#ifdef QAPT_ENABLED
-    , m_actions(new QAptActions(this))
-#endif
-{
-}
+    , m_canExit(true)
+{}
 
 bool MuonMainWindow::queryExit()
 {
@@ -64,9 +56,6 @@ void MuonMainWindow::setupActions()
 
     QShortcut *shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_M), this);
     connect(shortcut, SIGNAL(activated()), this, SLOT(easterEggTriggered()));
-#ifdef QAPT_ENABLED
-    m_actions->setupActions();
-#endif
 }
 
 void MuonMainWindow::easterEggTriggered()
@@ -98,10 +87,3 @@ void MuonMainWindow::setCanExit(bool canExit)
 {
     m_canExit = canExit;
 }
-
-void MuonMainWindow::setActionsEnabled(bool enabled)
-{
-#ifdef QAPT_ENABLED
-    m_actions->setActionsEnabled(enabled);
-#endif
-}
\ No newline at end of file
