@@ -558,11 +558,11 @@ void ApplicationBackend::integrateMainWindow(MuonMainWindow* w)
     m_aptify = w;
     QAptActions* apt = QAptActions::self();
     apt->setMainWindow(w);
-    if(m_aptBackendInitialized)
-        apt->setBackend(m_backend);
-    else
+    if(!m_aptBackendInitialized)
         connect(this, SIGNAL(aptBackendInitialized(QApt::Backend*)), apt, SLOT(setBackend(QApt::Backend*)));
-    connect(apt, SIGNAL(sourcesEditorClosed(bool)), SLOT(reload()));
+
+    if (apt->reloadWhenSourcesEditorFinished())
+        connect(apt, SIGNAL(sourcesEditorClosed(bool)), SLOT(reload()));
 }
 
 void ApplicationBackend::initBackend()
@@ -572,12 +572,11 @@ void ApplicationBackend::initBackend()
         QAptActions::self()->setReloadWhenEditorFinished(true);
     }
 
-    if (!m_backend->init())
-        QAptActions::self()->initError();
-    if (m_backend->xapianIndexNeedsUpdate()) {
-        // FIXME: transaction
+
+    QAptActions::self()->setBackend(m_backend);
+    if (m_backend->xapianIndexNeedsUpdate())
         m_backend->updateXapianIndex();
-    }
+
     m_aptBackendInitialized = true;
     emit aptBackendInitialized(m_backend);
 
