@@ -21,7 +21,6 @@
 #include "BodegaBackend.h"
 #include "BodegaResource.h"
 #include <Transaction/Transaction.h>
-#include <Transaction/TransactionModel.h>
 #include <bodega/session.h>
 #include <bodega/listballotsjob.h>
 #include <bodega/channelsjob.h>
@@ -76,6 +75,7 @@ QMap<QString,QString> retrieveCredentials()
 }
 
 BodegaBackend::BodegaBackend(QObject* parent, const QVariantList& args)
+// BodegaBackend::BodegaBackend(const QString& channel, const QString& iconName, QObject* parent)
     : AbstractResourcesBackend(parent)
 {
     const QVariantMap info = args.first().toMap();
@@ -91,7 +91,6 @@ BodegaBackend::BodegaBackend(QObject* parent, const QVariantList& args)
     m_session->setStoreId("VIVALDI-1");
     connect(m_session, SIGNAL(authenticated(bool)), SLOT(resetResources()));
     m_session->signOn();
-    connect(this, SIGNAL(transactionRemoved(Transaction*)), SIGNAL(updatesCountChanged()));
 }
 
 BodegaBackend::~BodegaBackend()
@@ -141,7 +140,7 @@ QVector<AbstractResource*> BodegaBackend::allResources() const
 QStringList BodegaBackend::searchPackageName(const QString& searchText){
     QStringList ret;
     foreach(AbstractResource* r, m_resourcesByName) {
-        if(r->name().contains(searchText) || r->comment().contains(searchText))
+        if(r->name().contains(searchText, Qt::CaseInsensitive) || r->comment().contains(searchText, Qt::CaseInsensitive))
             ret += r->packageName();
     }
     return ret;
@@ -155,16 +154,15 @@ AbstractResource* BodegaBackend::resourceByPackageName(const QString& name) cons
 AbstractBackendUpdater* BodegaBackend::backendUpdater() const
 { return 0; }
 
-void BodegaBackend::installApplication(AbstractResource* app, AddonList addons)
+void BodegaBackend::installApplication(AbstractResource* app, const QHash< QString, bool >& addons)
 {
     Q_ASSERT(m_transactions.count()==0);
     Q_ASSERT(addons.isEmpty());
     BodegaResource* res = qobject_cast<BodegaResource*>(app);
-    Transaction* t = new Transaction(this, res, Transaction::InstallRole);
-    TransactionModel *transModel = TransactionModel::global();
-    transModel->addTransaction(t);
+    Transaction* t = new Transaction(res, InstallApp);
+    emit transactionAdded(t);
     m_transactions.append(t);
-    t->setStatus(Transaction::CommittingStatus);
+    emit transactionsEvent(StartedCommitting, t);
     
     Bodega::InstallJob* job = m_session->install(res->assetOperations());
     t->setProperty("job", qVariantFromValue<QObject*>(job));
@@ -175,11 +173,10 @@ void BodegaBackend::removeApplication(AbstractResource* app)
 {
     Q_ASSERT(m_transactions.count()==0);
     BodegaResource* res = qobject_cast<BodegaResource*>(app);
-    Transaction* t = new Transaction(this, res, Transaction::RemoveRole);
-    TransactionModel *transModel = TransactionModel::global();
-    transModel->addTransaction(t);
+    Transaction* t = new Transaction(res, RemoveApp);
+    emit transactionAdded(t);
     m_transactions.append(t);
-    t->setStatus(Transaction::CommittingStatus);
+    emit transactionsEvent(StartedCommitting, t);
     
     Bodega::UninstallJob* job = m_session->uninstall(res->assetOperations());
     t->setProperty("job", qVariantFromValue<QObject*>(job));
@@ -197,12 +194,12 @@ void BodegaBackend::removeTransactionGeneric(QObject* job)
     }
     
     qDebug() << "finished" << job;
-    TransactionModel *transModel = TransactionModel::global();
     foreach(Transaction* t, m_transactions) {
         if(t->property("job").value<QObject*>() == job) {
-            t->setStatus(Transaction::DoneStatus);
-            transModel->removeTransaction(t);
+            t->setState(DoneState);
+            emit transactionRemoved(t);
             m_transactions.removeAll(t);
+            emit transactionsEvent(FinishedCommitting, t);
             delete t;
             break;
         }
@@ -216,14 +213,23 @@ void BodegaBackend::cancelTransaction(AbstractResource* app)
             Bodega::NetworkJob* job = qobject_cast<Bodega::NetworkJob*>(t->property("job").value<QObject*>());
             job->reply()->abort();
             m_transactions.removeAll(t);
-            TransactionModel::global()->cancelTransaction(t);
+            emit transactionCancelled(t);
             delete t;
             break;
         }
     }
 }
 
-AbstractReviewsBackend* BodegaBackend::reviewsBackend() const { return nullptr; }
+QPair< TransactionStateTransition, Transaction* > BodegaBackend::currentTransactionState() const {
+    Transaction* t = 0;
+    if(!m_transactions.isEmpty())
+        t = m_transactions.first();
+    return qMakePair<TransactionStateTransition, Transaction*>(StartedCommitting, t);
+}
+
+QList< Transaction* > BodegaBackend::transactions() const { return m_transactions; }
+
+AbstractReviewsBackend* BodegaBackend::reviewsBackend() const { return 0; }
 
 int BodegaBackend::updatesCount() const { return upgradeablePackages().count(); }
 
