@@ -80,7 +80,7 @@ QStringList DummyBackend::searchPackageName(const QString& searchText)
 {
     QStringList ret;
     foreach(AbstractResource* r, m_resources) {
-        if(r->name().contains(searchText) || r->comment().contains(searchText))
+        if(r->name().contains(searchText, Qt::CaseInsensitive) || r->comment().contains(searchText, Qt::CaseInsensitive))
             ret += r->packageName();
     }
     return ret;
