@@ -21,14 +21,23 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+// LibQApt includes
+#include <LibQApt/Globals>
+
 // Own includes
 #include "../libmuon/MuonMainWindow.h"
 
-class ResourcesUpdatesModel;
+class AbstractResourcesBackend;
 class KAction;
 class KDialog;
 class KMessageWidget;
 class KProcess;
+
+namespace QApt {
+    class Backend;
+    class Transaction;
+}
+
 class ChangelogWidget;
 class ProgressWidget;
 class UpdaterSettingsDialog;
@@ -41,29 +50,47 @@ public:
     MainWindow();
 
 private:
-    ResourcesUpdatesModel* m_updater;
+    QApt::Backend* backend() const;
+    QApt::Transaction *m_trans;
+    QString m_pipe;
 
     ProgressWidget *m_progressWidget;
     UpdaterWidget *m_updaterWidget;
     ChangelogWidget *m_changelogWidget;
     UpdaterSettingsDialog *m_settingsDialog;
+    KDialog *m_historyDialog;
     KMessageWidget *m_powerMessage;
-    KAction *m_applyAction;
+    KMessageWidget *m_distUpgradeMessage;
 
-    virtual void setActionsEnabled(bool enabled = true);
+    KAction *m_applyAction;
+    KAction *m_historyAction;
+
+    KProcess *m_checkerProcess;
+    AbstractResourcesBackend* m_apps;
 
 private Q_SLOTS:
     void initGUI();
     void initBackend();
     void setupActions();
-    void setupBackendsActions();
+    void transactionStatusChanged(QApt::TransactionStatus status);
+    void errorOccurred(QApt::ErrorCode error);
+    void reload();
+    void setActionsEnabled(bool enabled = true);
+    void checkForUpdates();
+    void startCommit();
+    void setupTransaction(QApt::Transaction *trans);
     void editSettings();
     void closeSettingsDialog();
+    void showHistoryDialog();
+    void closeHistoryDialog();
     void checkPlugState();
     void updatePlugState(bool plugged);
-    void progressingChanged();
-    void startedReloading();
-    void finishedReloading();
+    void checkDistUpgrade();
+    void checkerFinished(int res);
+    void launchDistUpgrade();
+
+Q_SIGNALS:
+    void backendReady(QApt::Backend *backend);
 };
 
 #endif // MAINWINDOW_H
