@@ -122,14 +122,15 @@ Qt::ItemFlags UpdateModel::flags(const QModelIndex &index) const
 
 QModelIndex UpdateModel::index(int row, int column, const QModelIndex &index) const
 {
-    if (index.isValid() && (index.column() < 0 && index.column() > 2)) {
+    // Bounds checks
+    if (!m_rootItem || row < 0 || column < 0 || column > 3 ||
+        (index.isValid() && index.column() != 0)) {
         return QModelIndex();
     }
 
     if (UpdateItem *parent = itemFromIndex(index)) {
-        if (UpdateItem *childItem = parent->child(row)) {
+        if (UpdateItem *childItem = parent->child(row))
             return createIndex(row, column, childItem);
-        }
     }
 
     return QModelIndex();
@@ -141,7 +142,7 @@ QModelIndex UpdateModel::parent(const QModelIndex &index) const
         return QModelIndex();
     }
 
-    UpdateItem *childItem = static_cast<UpdateItem*>(index.internalPointer());
+    UpdateItem *childItem = itemFromIndex(index);
     UpdateItem *parentItem = childItem->parent();
 
     if (parentItem == m_rootItem) {
@@ -153,6 +154,9 @@ QModelIndex UpdateModel::parent(const QModelIndex &index) const
 
 int UpdateModel::rowCount(const QModelIndex &parent) const
 {
+    if (parent.isValid() && parent.column() != 0)
+        return 0;
+
     UpdateItem *parentItem = itemFromIndex(parent);
 
     return parentItem->childCount();
@@ -167,7 +171,8 @@ int UpdateModel::columnCount(const QModelIndex &parent) const
 void UpdateModel::clear()
 {
     beginResetModel();
-    removeItem(QModelIndex());
+    delete m_rootItem;
+    m_rootItem = new UpdateItem();
     endResetModel();
 }
 
@@ -188,13 +193,16 @@ bool UpdateModel::removeItem(const QModelIndex &index)
 
 bool UpdateModel::removeRows(int position, int rows, const QModelIndex &index)
 {
-    bool success = false;
-    if (UpdateItem *parent = itemFromIndex(index)) {
-        beginRemoveRows(index, position, position + rows - 1);
-        success = parent->removeChildren(position, rows);
-        endRemoveRows();
-    }
-    return success;
+    if (!m_rootItem)
+        return false;
+
+    UpdateItem *item = index.isValid() ? itemFromIndex(index)
+                                       : m_rootItem;
+    beginRemoveRows(index, position, position + rows - 1);
+    item->removeChildren(position, rows);
+    endRemoveRows();
+
+    return true;
 }
 
 QModelIndexList UpdateModel::collectItems(const QModelIndex &parent) const
@@ -212,7 +220,7 @@ UpdateItem* UpdateModel::itemFromIndex(const QModelIndex &index) const
 {
     if (index.isValid())
          return static_cast<UpdateItem*>(index.internalPointer());
-     return m_rootItem;
+    return m_rootItem;
 }
 
 void UpdateModel::updateCheckStates()
@@ -255,6 +263,12 @@ bool UpdateModel::setData(const QModelIndex &index, const QVariant &value, int r
         }
 
         item->setChecked(newValue);
+        dataChanged(index, index);
+        if (type == UpdateItem::ItemType::ApplicationItem) {
+            QModelIndex parentIndex = index.parent();
+            dataChanged(parentIndex, parentIndex);
+        }
+
         emit checkApps(apps, newValue);
         return true;
     }
